@@ -12,23 +12,30 @@
 #include <QSettings>
 #include <QTimeZone>
 
+#include <qqmlintegration.h>
+
+class QJSEngine;
+class QQmlEngine;
+
 class SavedLocationsModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
     static SavedLocationsModel *instance();
+    static SavedLocationsModel *create(QQmlEngine *qmlEngine, QJSEngine *jsEngine);
 
     enum Roles {
         NameRole = Qt::DisplayRole,
         TimeStringRole = Qt::UserRole + 1,
         RelativeTimeRole,
+        RelativeDaysRole,
         CityRole,
         IdRole,
     };
 
-    explicit SavedLocationsModel(QObject *parent = nullptr);
-
     Q_INVOKABLE void removeLocation(int index);
 
     int rowCount(const QModelIndex &parent) const override;
@@ -39,6 +46,8 @@ public Q_SLOTS:
     void load();
 
 private:
+    explicit SavedLocationsModel(QObject *parent = nullptr);
+
     std::vector<QTimeZone> m_timeZones;
     QSettings m_settings;
 };
