@@ -1,20 +1,32 @@
 // SPDX-FileCopyrightText: 2020 Han Young <hanyoung@protonmail.com>
 // SPDX-FileCopyrightText: 2020-2024 Devin Lin <devin@kde.org>
+// SPDX-FileCopyrightText: 2025 Kai Uwe Broulik <kde@broulik.de>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #pragma once
 
-#include <QDateTime>
+#include <QElapsedTimer>
 #include <QObject>
 #include <QTimer>
 
+#include <optional>
+
+#include <qqmlintegration.h>
+
+class QJSEngine;
+class QQmlEngine;
+
 // class for the timer that manages the stopwatch
 class StopwatchTimer : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
+
     Q_PROPERTY(bool paused READ paused NOTIFY pausedChanged)
     Q_PROPERTY(bool stopped READ stopped NOTIFY stoppedChanged)
     Q_PROPERTY(qint64 elapsedTime READ elapsedTime NOTIFY timeChanged)
+    Q_PROPERTY(QString display READ display NOTIFY timeChanged)
     Q_PROPERTY(QString hours READ hoursDisplay NOTIFY timeChanged)
     Q_PROPERTY(QString minutes READ minutesDisplay NOTIFY timeChanged)
     Q_PROPERTY(QString seconds READ secondsDisplay NOTIFY timeChanged)
@@ -22,15 +34,16 @@ class StopwatchTimer : public QObject
 
 public:
     static StopwatchTimer *instance();
-    explicit StopwatchTimer(QObject *parent = nullptr);
+    static StopwatchTimer *create(QQmlEngine *qmlEngine, QJSEngine *jsEngine);
 
-    bool paused();
-    bool stopped();
+    bool paused() const;
+    bool stopped() const;
 
     qint64 hours() const;
     qint64 minutes() const;
     qint64 seconds() const;
     qint64 small() const;
+    QString display() const;
     QString hoursDisplay() const;
     QString minutesDisplay() const;
     QString secondsDisplay() const;
@@ -48,20 +61,11 @@ Q_SIGNALS:
     void resetTriggered();
 
 private:
-    // when the stopwatch started
-    qint64 m_timerStartStamp = 0;
+    explicit StopwatchTimer(QObject *parent = nullptr);
 
-    // when the last pause started
-    qint64 m_pausedStamp = 0;
+    QElapsedTimer m_elapsedTimer;
 
-    // how much total time has been spent paused since the stopwatch started
-    qint64 m_pausedElapsed = 0;
+    std::optional<qint64> m_pausedTime;
 
-    // whether the stopwatch is fully stopped (laps cleared, start at 0)
-    bool m_stopped = true;
-
-    // whether the stopwatch is stopped or paused
-    bool m_paused = false;
-
-    QTimer *m_timer = nullptr;
+    QTimer m_reportTimer;
 };
