@@ -8,6 +8,7 @@
 
 #include "alarmmodel.h"
 #include "kclockdsettings.h"
+#include "kclockrunner.h"
 #include "kclocksettingsadaptor.h"
 #include "timermodel.h"
 #include "utilities.h"
@@ -35,6 +36,7 @@ QCommandLineParser *createParser()
 
 int main(int argc, char *argv[])
 {
+    QApplication::setDesktopSettingsAware(false);
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kclockd");
@@ -46,6 +48,7 @@ int main(int argc, char *argv[])
                          i18n("© 2020-2022 KDE Community"));
     aboutData.addAuthor(i18n("Devin Lin"), QLatin1String(), QStringLiteral("devin@kde.org"));
     aboutData.addAuthor(i18n("Han Young"), QLatin1String(), QStringLiteral("hanyoung@protonmail.com"));
+    aboutData.addAuthor(i18n("Kai Uwe Broulik"), i18nc("Author", "Desktop Integration"), QStringLiteral("kde@broulik.de"));
     KAboutData::setApplicationData(aboutData);
 
     KCrash::initialize();
@@ -75,8 +78,11 @@ int main(int argc, char *argv[])
     new KClockSettingsAdaptor(KClockSettings::self());
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Settings"), KClockSettings::self());
 
+    new KClockRunner(&app);
+
     // save config
     QObject::connect(KClockSettings::self(), &KClockSettings::timeFormatChanged, KClockSettings::self(), &KClockSettings::save);
+    QObject::connect(KClockSettings::self(), &KClockSettings::timerNotificationChanged, KClockSettings::self(), &KClockSettings::save);
 
     // start alarm polling
     AlarmModel::instance()->configureWakeups();
